@@ -21,7 +21,6 @@ from django.shortcuts import redirect, resolve_url
 from django.urls import reverse
 from django.utils.decorators import method_decorator
 from django.utils.functional import cached_property
-from django.utils.http import is_safe_url
 from django.utils.module_loading import import_string
 from django.utils.translation import gettext as _
 from django.views.decorators.cache import never_cache
@@ -50,7 +49,14 @@ from .utils import (
 )
 
 try:
-    from otp_yubikey.models import ValidationService, RemoteYubikeyDevice
+    from django.utils.http import url_has_allowed_host_and_scheme
+except ImportError:
+    from django.utils.http import (
+        is_safe_url as url_has_allowed_host_and_scheme,
+    )
+
+try:
+    from otp_yubikey.models import RemoteYubikeyDevice, ValidationService
 except ImportError:
     ValidationService = RemoteYubikeyDevice = None
 
@@ -196,7 +202,7 @@ class LoginView(SuccessURLAllowedHostsMixin, IdempotentSessionWizardView):
             self.redirect_field_name,
             self.request.GET.get(self.redirect_field_name, '')
         )
-        url_is_safe = is_safe_url(
+        url_is_safe = url_has_allowed_host_and_scheme(
             url=redirect_to,
             allowed_hosts=self.get_success_url_allowed_hosts(),
             require_https=self.request.is_secure(),
